==> Papyrus-Update-3.1.0.zip: org/eclipse/papyrus/uml/service/types/internal/ui/messages/Messages.java <==
/*****************************************************************************
 * Copyright (c) 2013, 2016 CEA LIST, Christian W. Damus, and others.
 * 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *  Juan Cadavid (CEA LIST) juan.cadavid@cea.fr - Initial API and implementation
 *  Christian W. Damus - bug 485220
 *  
 *****************************************************************************/
package org.eclipse.papyrus.uml.service.types.internal.ui.messages;

import org.eclipse.osgi.util.NLS;

public class Messages extends NLS {

	private static final String BUNDLE_NAME = "org.eclipse.papyrus.uml.service.types.internal.ui.messages.messages"; //$NON-NLS-1$

	public static String AbstractAssociationSelectionDialog_1;

	public static String AbstractAssociationSelectionDialog_2;

	public static String AbstractAssociationSelectionDialog_4;

	public static String AbstractAssociationSelectionDialog_5;

	public static String AbstractTemplateParameterConfigurationDialog_0;

	public static String AbstractTemplateParameterConfigurationDialog_1;

	public static String AbstractTemplateParameterConfigurationDialog_10;

	public static String AbstractTemplateParameterConfigurationDialog_14;

	public static String AbstractTemplateParameterConfigurationDialog_15;

	public static String AbstractTemplateParameterConfigurationDialog_16;

	public static String AbstractTemplateParameterConfigurationDialog_17;

	public static String AbstractTemplateParameterConfigurationDialog_3;

	public static String AbstractTemplateParameterConfigurationDialog_4;

	public static String AbstractTemplateParameterConfigurationDialog_9;

	public static String AssociationSelectionDialog_0;

	public static String CollaborationRoleCreateCommand_CollaborationRoleCreation_Message;

	public static String CollaborationRoleCreateCommand_CollaborationRoleCreation_Title;

	public static String InformationFlowCreateCommand_0;

	public static String InformationFlowCreateCommand_1;

	public static String InformationFlowCreateCommand_2;

	public static String InformationItemElementTreeSelectionDialog_0;

	public static String InformationItemValidator_0;

	public static String InformationItemValidator_1;

	public static String InformationItemValidator_2;

	static {
		// initialize resource bundle
		NLS.initializeMessages(BUNDLE_NAME, Messages.class);
	}

	private Messages() {
	}
}

==> Papyrus-Update-3.2.0.zip: org/eclipse/papyrus/uml/service/types/internal/ui/messages/Messages.java <==
/*****************************************************************************
 * Copyright (c) 2013, 2016 CEA LIST, Christian W. Damus, and others.
 * 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *  Juan Cadavid (CEA LIST) juan.cadavid@cea.fr - Initial API and implementation
 *  Christian W. Damus - bug 485220
 *  
 *****************************************************************************/
package org.eclipse.papyrus.uml.service.types.internal.ui.messages;

import org.eclipse.osgi.util.NLS;

public class Messages extends NLS {

	private static final String BUNDLE_NAME = "org.eclipse.papyrus.uml.service.types.internal.ui.messages.messages"; //$NON-NLS-1$

	public static String AbstractAssociationSelectionDialog_1;

	public static String AbstractAssociationSelectionDialog_2;

	public static String AbstractAssociationSelectionDialog_4;

	public static String AbstractAssociationSelectionDialog_5;

	public static String AbstractTemplateParameterConfigurationDialog_0;

	public static String AbstractTemplateParameterConfigurationDialog_1;

	public static String AbstractTemplateParameterConfigurationDialog_10;

	public static String AbstractTemplateParameterConfigurationDialog_14;

	public static String AbstractTemplateParameterConfigurationDialog_15;

	public static String AbstractTemplateParameterConfigurationDialog_16;

	public static String AbstractTemplateParameterConfigurationDialog_17;

	public static String AbstractTemplateParameterConfigurationDialog_3;

	public static String AbstractTemplateParameterConfigurationDialog_4;

	public static String AbstractTemplateParameterConfigurationDialog_9;

	public static String AssociationSelectionDialog_0;

	public static String CollaborationRoleCreateCommand_CollaborationRoleCreation_Message;

	public static String CollaborationRoleCreateCommand_CollaborationRoleCreation_Title;

	public static String InformationFlowCreateCommand_0;

	public static String InformationFlowCreateCommand_1;

	public static String InformationFlowCreateCommand_2;

	public static String InformationItemElementTreeSelectionDialog_0;

	public static String InformationItemValidator_0;

	public static String InformationItemValidator_1;

	public static String InformationItemValidator_2;

	public static String UMLElementTypePreferencePage_KeepStereotypeApplicationText;

	public static String UMLElementTypePreferencePage_PageDescription;

	static {
		// initialize resource bundle
		NLS.initializeMessages(BUNDLE_NAME, Messages.class);
	}

	private Messages() {
	}
}
